@@ -12,8 +12,7 @@ matexpo <- function(x)
     if (!is.matrix(x)) stop('"x" must be a matrix')
     nr <- dim(x)[1]
     if (nr != dim(x)[2]) stop('"x" must be a square matrix')
-    ans <- .C("mat_expo", as.double(x), as.integer(nr),
-              PACKAGE = "ape")[[1]]
+    ans <- .C(mat_expo, as.double(x), as.integer(nr))[[1]]
     dim(ans) <- c(nr, nr)
     ans
 }
