@@ -1,15 +1,15 @@
-### mst.R (2006-11-08)
-###
-###     Minimum Spanning Tree
-###
-### Copyright 2002-2006 Yvonnick Noel, Julien Claude, and Emmanuel Paradis
-###
-### This file is part of the R-package `ape'.
-### See the file ../COPYING for licensing issues.
+## mst.R (2020-07-02)
+
+##   Minimum Spanning Tree
+
+## Copyright 2002-2006 Yvonnick Noel, Julien Claude, and Emmanuel Paradis
+
+## This file is part of the R-package `ape'.
+## See the file ../COPYING for licensing issues.
 
 mst <- function(X)
 {
-    if (class(X) == "dist") X <- as.matrix(X)
+    if (inherits(X, "dist")) X <- as.matrix(X)
     n <- dim(X)[1]
     N <- matrix(0, n, n)
     tree <- NULL
